pub struct EffectiveGraphchainInfo {
pub acquire_timeout: u64,
pub composite_alpha: CompositeAlphaFlagsKHR,
pub clipped: bool,
pub frame_count: usize,
pub height: u32,
pub image_count: usize,
pub present_mode: PresentModeKHR,
pub surface: SurfaceFormatKHR,
pub width: u32,
/* private fields */
}Expand description
Effective runtime information for a live Graphchain.
Fields
acquire_timeout: u64Timeout in nanoseconds used when acquiring the next image.
composite_alpha: CompositeAlphaFlagsKHRActive alpha compositing mode used by the presentation engine.
clipped: boolWhether pixels obscured by other windows on the native surface are clipped.
frame_count: usizeThe effective number of tracked frame slots.
height: u32The live height of the surface.
image_count: usizeThe live swapchain image count.
present_mode: PresentModeKHRvk::PresentModeKHR determines timing and queueing with which frames are displayed.
surface: SurfaceFormatKHRThe format and color space of the surface.
width: u32The live width of the surface.
Implementations
Sourceimpl EffectiveGraphchainInfo
impl EffectiveGraphchainInfo
Sourcepub fn builder() -> GraphchainInfoBuilder
pub fn builder() -> GraphchainInfoBuilder
Creates a default GraphchainInfoBuilder.
Sourcepub fn into_builder(self) -> GraphchainInfoBuilder
pub fn into_builder(self) -> GraphchainInfoBuilder
Converts an EffectiveGraphchainInfo into a GraphchainInfoBuilder.
Sourcepub fn into_requested_info(self) -> GraphchainInfo
pub fn into_requested_info(self) -> GraphchainInfo
Converts this effective runtime info back into requested graphchain info.