pub struct GraphchainInfo {
pub acquire_timeout: u64,
pub composite_alpha: CompositeAlphaFlagsKHR,
pub clipped: bool,
pub frame_capacity: usize,
pub height: u32,
pub min_image_count: u32,
pub present_mode: PresentModeKHR,
pub surface: SurfaceFormatKHR,
pub width: u32,
}Expand description
Information used to create a Graphchain instance.
Fields
acquire_timeout: u64Timeout in nanoseconds used when acquiring the next image.
Do not use u64::MAX on surfaces where acquire forward progress cannot be guaranteed.
composite_alpha: CompositeAlphaFlagsKHRAlpha compositing mode used by the presentation engine.
clipped: boolWhether to clip pixels obscured by other windows on the native surface.
frame_capacity: usizeThe requested frame capacity used for in-flight graphchain work.
The effective live capacity may be raised at runtime to match the swapchain image count.
That resolved value is reflected through EffectiveGraphchainInfo.
height: u32The initial height of the surface.
min_image_count: u32The minimum number of presentable images that the application needs.
present_mode: PresentModeKHRvk::PresentModeKHR determines timing and queueing with which frames are displayed.
surface: SurfaceFormatKHRThe format and color space of the surface.
width: u32The initial width of the surface.
Implementations
Sourceimpl GraphchainInfo
impl GraphchainInfo
Sourcepub fn new(width: u32, height: u32, surface: SurfaceFormatKHR) -> GraphchainInfo
pub fn new(width: u32, height: u32, surface: SurfaceFormatKHR) -> GraphchainInfo
Specifies a default graphchain with the given width, height and format values.
Sourcepub fn builder() -> GraphchainInfoBuilder
pub fn builder() -> GraphchainInfoBuilder
Creates a default GraphchainInfoBuilder.
Sourcepub fn into_builder(self) -> GraphchainInfoBuilder
pub fn into_builder(self) -> GraphchainInfoBuilder
Converts a GraphchainInfo into a GraphchainInfoBuilder.
Sourcepub fn into_swapchain_info(self) -> SwapchainInfo
pub fn into_swapchain_info(self) -> SwapchainInfo
Converts this graphchain info into low-level swapchain info.