#[non_exhaustive]pub struct SubmissionQueryPool {
pub timestamps: TimestampQueryPool,
}Expand description
Query result proxies for graph work submitted by Graphchain::present_image.
These handles are detached from the frame slot when it is reused. Timestamp completion is
reported after Graphchain observes the submitted frame fence signal.
This does not describe presentation status; presentation failures are reported through
GraphchainError.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timestamps: TimestampQueryPoolTimestamp query results for the submitted work.