Window

Struct Window 

pub struct Window {
    pub device: Device,
    /* private fields */
}
A convenience wrapper that owns a winit event loop and a compatible vk-graph device.

Fields

device: Device

A device which is compatible with this window.

Note: This field is read-only.

Implementations

Source

impl Window

pub fn new() -> Result<Self, WindowError>

Creates a window using the default WindowBuilder configuration.

pub fn builder() -> WindowBuilder

Creates a builder for configuring a Window before construction.

pub fn run<F>(self, draw_fn: F) -> Result<(), WindowError>
where F: FnMut(FrameContext<'_>),

Runs the application event loop and invokes draw_fn for each rendered frame.