WindowBuilder

Struct WindowBuilder 

pub struct WindowBuilder { /* private fields */ }
Builder for configuring and constructing a Window.

Implementations

Source

impl WindowBuilder

pub fn build(self) -> Result<Window, WindowError>

Builds the window, event loop, and compatible vk-graph device.

pub fn command_buffer_count(self, count: usize) -> Self

Specifies the number of in-flight command buffers, which should be greater than or equal to the desired swapchain image count.

More command buffers mean less time waiting for previously submitted frames to complete, but more memory in use.

Generally a value of one or two greater than desired image count produces the smoothest animation.

pub fn debug(self, enabled: bool) -> Self

Enables Vulkan graphics debugging layers.

NOTE: Validation errors will only park the current thread for debugger attach when the process is attached to an interactive terminal. Otherwise they continue after logging.

Platform-specific

macOS: Has no effect.

pub fn desired_surface_format<F>(self, f: F) -> Self
where F: 'static + Fn(&[SurfaceFormatKHR]) -> SurfaceFormatKHR,

A function to select the desired swapchain surface image format.

By default linear color space will be selected unless it is not available.

pub fn min_image_count(self, count: u32) -> Self

The minimum number of presentable images that the application needs. The implementation will either create the swapchain with at least that many images, or it will fail to create the swapchain.

More images introduce more display lag, but smoother animation.

pub fn fullscreen_mode(self, mode: FullscreenMode) -> Self

Sets up fullscreen mode. In addition, decorations are set to false and maximized is set to true.

Note

There are additional options offered by winit which can be accessed using the window function.

pub fn v_sync(self, enabled: bool) -> Self

When true, requests presentation synchronized to the display refresh.

Note

Applies only to exclusive fullscreen mode.

pub fn window<WindowFn>(self, f: WindowFn) -> Self

Allows deeper customization of the window, if needed.

pub fn window_mode(self) -> Self

Sets up “windowed” mode, which is the opposite of fullscreen.

Note

There are additional options offered by winit which can be accessed using the window function.