winit window, event loop, and swapchain helpers for vk-graph.
Re-exports
pub use winit;
Modules
- graphchain
- Window graphchain creation, acquisition, and presentation helpers.
Structs
- Frame
Context - A request to render a single frame to the provided graph.
- Window
- A convenience wrapper that owns a
winitevent loop and a compatiblevk-graphdevice. - Window
Builder - Builder for configuring and constructing a
Window.
Enums
- Fullscreen
Mode - Describes a screen mode for display.
- Window
Error - Errors produced while creating or running a
Window.
Type Aliases
- Surface
Format Fn - A closure type for picking surface formats.