pub struct Graphchain {
pub info: EffectiveGraphchainInfo,
pub swapchain: Swapchain,
/* private fields */
}Expand description
A physical display interface.
Fields
info: EffectiveGraphchainInfoEffective runtime information for the live graphchain.
Calls to set_info update the requested configuration. This field is
updated lazily after the next successful acquire recreates the swapchain.
Note: This field is read-only.
swapchain: SwapchainThe driver swapchain backing this graphchain.
Note: This field is read-only.
Implementations
Sourceimpl Graphchain
impl Graphchain
Sourcepub fn new(
surface: Surface,
info: impl Into<GraphchainInfo>,
) -> Result<Self, DriverError>
pub fn new( surface: Surface, info: impl Into<GraphchainInfo>, ) -> Result<Self, DriverError>
Constructs a new Graphchain object.
Sourcepub fn acquire_next_image(
&mut self,
) -> Result<Option<SwapchainImage>, GraphchainError>
pub fn acquire_next_image( &mut self, ) -> Result<Option<SwapchainImage>, GraphchainError>
Acquires the next available swapchain image for rendering.
Sourcepub fn present_image<P>(
&mut self,
pool: &mut P,
graph: Graph,
image_node: SwapchainImageNode,
queue_index: u32,
) -> Result<SubmissionQueryPool, GraphchainError>
pub fn present_image<P>( &mut self, pool: &mut P, graph: Graph, image_node: SwapchainImageNode, queue_index: u32, ) -> Result<SubmissionQueryPool, GraphchainError>
Displays the given swapchain image using passes specified in graph, if possible.
Sourcepub fn set_info(&mut self, info: impl Into<GraphchainInfo>)
pub fn set_info(&mut self, info: impl Into<GraphchainInfo>)
Updates the requested information which controls the graphchain.
Previously acquired swapchain images should be discarded after calling this function.
The live effective info field updates acquire_timeout
immediately. Other fields are updated lazily after the next successful acquire recreates the
swapchain and reflects the runtime values that were actually selected.