pub struct Window {
pub device: Device,
/* private fields */
}Expand description
A convenience wrapper that owns a winit event loop and a compatible vk-graph device.
Fields
device: DeviceA device which is compatible with this window.
Note: This field is read-only.
Implementations
Sourceimpl Window
impl Window
Sourcepub fn new() -> Result<Self, WindowError>
pub fn new() -> Result<Self, WindowError>
Creates a window using the default WindowBuilder configuration.
Sourcepub fn builder() -> WindowBuilder
pub fn builder() -> WindowBuilder
Creates a builder for configuring a Window before construction.
Sourcepub fn run<F>(self, draw_fn: F) -> Result<(), WindowError>where
F: FnMut(FrameContext<'_>),
pub fn run<F>(self, draw_fn: F) -> Result<(), WindowError>where
F: FnMut(FrameContext<'_>),
Runs the application event loop and invokes draw_fn for each rendered frame.